@@ -1,7 +1,6 @@
 #' @title Density ggplot.
-#' 
 #' @description Density ggplot that is not coloured and not facetted.
-#' @param data An ungrouped summarised tibble or dataframe in a structure to be transformed to density statistics. Required input.
+#' @param data A data frame in a structure to be transformed to density statistics. Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale. Required input.
 #' @param pal Character vector of hex codes. 
 #' @param alpha_fill The opacity of the fill. Defaults to 0.5.  
@@ -11,7 +10,7 @@
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 75. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_breaks_n For a numeric x variable, the desired number of intervals on the x scale, as calculated by the  
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -45,7 +44,7 @@
 #' 
 gg_density <- function(data,
                        x_var,
-                       pal = pal_viridis_reorder(1),
+                       pal = pal_viridis_mix(1),
                        alpha_fill = 0.5,
                        alpha_line = 1,
                        size_line = 0.5,
@@ -53,7 +52,7 @@ gg_density <- function(data,
                        title_wrap = 80,
                        subtitle = NULL,
                        subtitle_wrap = 80,
-                       x_balance = FALSE,
+                       x_zero_mid = FALSE,
                        x_breaks_n = 5,
                        x_expand = c(0, 0),
                        x_labels = scales::label_comma(),
@@ -68,7 +67,7 @@ gg_density <- function(data,
                        y_title_wrap = 50,
                        caption = NULL,
                        caption_wrap = 80,
-                       theme = gg_theme(gridlines_h = TRUE),
+                       theme = gg_theme(y_grid = TRUE),
                        model_bw = "nrd0",
                        model_adjust = 1,
                        model_kernel = "gaussian",
@@ -106,10 +105,10 @@ gg_density <- function(data,
                  fill = pal_fill, 
                  size = size_line) 
   #x scale  
-  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
   x_zero <- x_zero_list[[1]]
   x_zero_line <- x_zero_list[[2]]
-  x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
+  x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
   x_limits <- c(min(x_breaks), max(x_breaks))
   
   if (mobile == TRUE) {
@@ -168,8 +167,8 @@ gg_density <- function(data,
 
 #' @title Density ggplot that is coloured.
 #' 
-#' @description Density ggplot that is coloured but not facetted.
-#' @param data An ungrouped summarised tibble or dataframe in a structure to be transformed to density statistics. Required input.
+#' @description Density ggplot that is coloured, but not facetted.
+#' @param data A data frame in a structure to be transformed to density statistics. Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale. Required input.
 #' @param col_var Unquoted categorical variable to colour density areas. Required input.
 #' @param pal Character vector of hex codes. 
@@ -182,7 +181,7 @@ gg_density <- function(data,
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 75. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_breaks_n For a numeric x variable, the desired number of intervals on the x scale, as calculated by the  
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -234,7 +233,7 @@ gg_density_col <- function(data,
                            title_wrap = 80,
                            subtitle = NULL,
                            subtitle_wrap = 80,
-                           x_balance = FALSE,
+                           x_zero_mid = FALSE,
                            x_breaks_n = 5,
                            x_expand = c(0, 0),
                            x_labels = scales::label_comma(),
@@ -254,7 +253,7 @@ gg_density_col <- function(data,
                            col_title_wrap = 25,
                            caption = NULL,
                            caption_wrap = 80,
-                           theme = gg_theme(gridlines_h = TRUE),
+                           theme = gg_theme(y_grid = TRUE),
                            model_bw = "nrd0",
                            model_adjust = 1,
                            model_kernel = "gaussian",
@@ -302,7 +301,7 @@ gg_density_col <- function(data,
   }
   else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  if (is.null(pal)) pal <- pal_d3_mix(col_n)
   else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -321,10 +320,10 @@ gg_density_col <- function(data,
                  size = size_line) 
   
   #x scale  
-  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
   x_zero <- x_zero_list[[1]]
   x_zero_line <- x_zero_list[[2]]
-  x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
+  x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
   x_limits <- c(min(x_breaks), max(x_breaks))
 
   if (mobile == TRUE) {
@@ -374,15 +373,6 @@ gg_density_col <- function(data,
       name = stringr::str_wrap(col_title, col_title_wrap)
     )
   
-  if (mobile == TRUE & col_legend_none == TRUE) {
-    plot <- plot +
-      guides(col = guide_legend(ncol = 1), 
-             fill = guide_legend(ncol = 1))
-  }
-  
-  if (col_legend_none == TRUE) plot <- plot +
-    theme(legend.position = "none")
-
   #titles
   if (mobile == FALSE) {
     plot <- plot +
@@ -406,13 +396,18 @@ gg_density_col <- function(data,
       theme_mobile_extra()
   }
   
+  if (col_legend_none == TRUE) {
+    plot <- plot +
+      theme(legend.position = "none")
+  }
+
   return(plot)
 }
 
 #' @title Density ggplot that is facetted.
 #' 
 #' @description Density ggplot that is facetted, but not coloured.
-#' @param data An ungrouped summarised tibble or dataframe in a structure to be transformed to density statistics. Required input.
+#' @param data A data frame in a structure to be transformed to density statistics. Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale. Required input.
 #' @param facet_var Unquoted categorical variable to facet the data by. Required input.
 #' @param pal Character vector of hex codes. 
@@ -423,7 +418,7 @@ gg_density_col <- function(data,
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 75. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_breaks_n For a numeric x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 2. 
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -464,7 +459,7 @@ gg_density_col <- function(data,
 gg_density_facet <- function(data,
                              x_var,
                              facet_var,
-                             pal = pal_viridis_reorder(1),
+                             pal = pal_viridis_mix(1),
                              alpha_fill = 0.5,
                              alpha_line = 1,
                              size_line = 0.5,
@@ -472,7 +467,7 @@ gg_density_facet <- function(data,
                              title_wrap = 80,
                              subtitle = NULL,
                              subtitle_wrap = 80,
-                             x_balance = FALSE,
+                             x_zero_mid = FALSE,
                              x_breaks_n = 2,
                              x_expand = c(0, 0),
                              x_labels = scales::label_comma(),
@@ -493,7 +488,7 @@ gg_density_facet <- function(data,
                              facet_scales = "fixed",
                              caption = NULL,
                              caption_wrap = 80,
-                             theme = gg_theme(gridlines_h = TRUE), 
+                             theme = gg_theme(y_grid = TRUE), 
                              model_bw = "nrd0",
                              model_adjust = 1,
                              model_kernel = "gaussian",
@@ -549,10 +544,10 @@ gg_density_facet <- function(data,
   
   #x scale
   if (facet_scales %in% c("fixed", "free_y")) {
-    x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+    x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
     x_zero <- x_zero_list[[1]]
     x_zero_line <- x_zero_list[[2]]
-    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
+    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
     x_limits <- c(min(x_breaks), max(x_breaks))
 
     plot <- plot +
@@ -604,7 +599,7 @@ gg_density_facet <- function(data,
 #' @title Density ggplot that is coloured and facetted.
 #' 
 #' @description Density ggplot that is coloured and facetted.
-#' @param data An ungrouped summarised tibble or dataframe in a structure to be transformed to density statistics. Required input.
+#' @param data A data frame in a structure to be transformed to density statistics. Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale. Required input.
 #' @param col_var Unquoted categorical variable to colour density areas. Required input.
 #' @param facet_var Unquoted categorical variable to facet the data by. Required input.
@@ -618,7 +613,7 @@ gg_density_facet <- function(data,
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 75. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_breaks_n For a numeric x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 2. 
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
@@ -678,7 +673,7 @@ gg_density_col_facet <- function(data,
                                  subtitle = NULL,
                                  subtitle_wrap = 80,
                                  x_breaks_n = 2,
-                                 x_balance = FALSE,
+                                 x_zero_mid = FALSE,
                                  x_expand = c(0, 0),
                                  x_labels = scales::label_comma(),
                                  x_title = NULL,
@@ -703,7 +698,7 @@ gg_density_col_facet <- function(data,
                                  facet_scales = "fixed",
                                  caption = NULL,
                                  caption_wrap = 80, 
-                                 theme = gg_theme(gridlines_h = TRUE), 
+                                 theme = gg_theme(y_grid = TRUE), 
                                  model_bw = "nrd0",
                                  model_adjust = 1,
                                  model_kernel = "gaussian",
@@ -764,7 +759,7 @@ gg_density_col_facet <- function(data,
   }
   else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  if (is.null(pal)) pal <- pal_d3_mix(col_n)
   else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -784,10 +779,10 @@ gg_density_col_facet <- function(data,
   
   #x scale
   if (facet_scales %in% c("fixed", "free_y")) {
-    x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+    x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
     x_zero <- x_zero_list[[1]]
     x_zero_line <- x_zero_list[[2]]
-    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
+    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
     x_limits <- c(min(x_breaks), max(x_breaks))
 
     plot <- plot +
@@ -829,9 +824,6 @@ gg_density_col_facet <- function(data,
   }
   
   #colour, titles & facetting
-  if (col_legend_none == TRUE) plot <- plot +
-    theme(legend.position = "none")
-  
   plot <- plot +
     scale_colour_manual(
       values = pal_line,
@@ -856,5 +848,10 @@ gg_density_col_facet <- function(data,
     ) +
     facet_wrap(vars(!!facet_var), labeller = as_labeller(facet_labels), scales = facet_scales, ncol = facet_ncol, nrow = facet_nrow)
   
+  if (col_legend_none == TRUE) {
+    plot <- plot +
+      theme(legend.position = "none")
+  }
+  
   return(plot)
 }
