@@ -1,20 +1,20 @@
 #' @title Horizontal boxplot ggplot.
 #' @description Horizontal boxplot ggplot that is not coloured and not facetted.
-#' @param data An ungrouped summarised tibble or dataframe generally in a structure to be transformed to boxplot statistics (or alternatively in a structure of summary boxplot statistics). Required input.
+#' @param data An ungrouped summarised tibble or data frame generally in a structure to be transformed to boxplot statistics (or alternatively in a structure of summary boxplot statistics). Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale for when stat = "boxplot" is selected. 
 #' @param y_var Unquoted categorical variable to be on the y scale (i.e. character, factor, or logical). Required input.
 #' @param pal Character vector of hex codes. 
 #' @param alpha_fill The opacity of the fill. Defaults to 0.5. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param alpha_point The opacity of the outlier points. Defaults to 1. 
-#' @param size_line The size of the outlines of boxplots.
+#' @param size_line The size of the outlines of boxplots. Defaults to 0.5.
 #' @param size_point The size of the outlier points. Defaults to 1.5.
-#' @param size_width Width of boxes. Defaults to 0.5.
+#' @param width Width of boxes. Defaults to 0.5.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 60. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 60. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. Use ggplot2::waiver() to keep x labels untransformed.
@@ -69,24 +69,24 @@
 #'             x_title = "Body mass g",
 #'             x_breaks_n = 4) +
 #'   ggplot2::geom_point(ggplot2::aes(x = species, y = body_mass_g), 
-#'             size = 0.75, col = pal_viridis_reorder(1), 
+#'             size = 0.75, col = pal_viridis_mix(1), 
 #'             data = outliers)
 #'   
 gg_hboxplot <- function(data,
                     x_var = NULL,
                     y_var,
-                    pal = pal_viridis_reorder(1),
+                    pal = pal_viridis_mix(1),
                     alpha_fill = 0.5,
                     alpha_line = 1,
                     alpha_point = 1,
                     size_line = 0.5,
                     size_point = 1.5,
-                    size_width = 0.5,
+                    width = 0.5,
                     title = NULL,
                     title_wrap = 75,
                     subtitle = NULL,
                     subtitle_wrap = 75,
-                    x_balance = FALSE,
+                    x_zero_mid = FALSE,
                     x_breaks_n = 5,
                     x_expand = c(0, 0),
                     x_labels = scales::label_comma(),
@@ -102,7 +102,7 @@ gg_hboxplot <- function(data,
                     y_title_wrap = 50,
                     caption = NULL,
                     caption_wrap = 75,
-                    theme = gg_theme(gridlines_v = TRUE),
+                    theme = gg_theme(x_grid = TRUE),
                     stat = "boxplot",
                     xmin_var = NULL,
                     xlower_var = NULL,
@@ -176,7 +176,7 @@ gg_hboxplot <- function(data,
   
   #fundamentals
   plot <- ggplot(data) +
-    coord_flip(clip = "off") +
+    coord_flip() +
     theme 
   
   if (stat == "boxplot") {
@@ -187,7 +187,7 @@ gg_hboxplot <- function(data,
         fill = pal_fill,
         col = pal_line, 
         size = size_line, 
-        width = size_width,
+        width = width,
         outlier.alpha = alpha_point,
         outlier.size = size_point
       )
@@ -207,7 +207,7 @@ gg_hboxplot <- function(data,
         fill = pal_fill,
         col = pal_line, 
         size = size_line, 
-        width = size_width,
+        width = width,
         outlier.alpha = alpha_point,
         outlier.size = size_point
       )
@@ -218,7 +218,7 @@ gg_hboxplot <- function(data,
     scale_x_discrete(expand = y_expand, labels = y_labels)
 
   #x scale
-  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
   x_zero <- x_zero_list[[1]]
   x_zero_line <- x_zero_list[[2]]
   
@@ -227,7 +227,7 @@ gg_hboxplot <- function(data,
       scale_y_continuous(expand = x_expand, breaks = c(0, 1), labels = x_labels, limits = c(0, 1))
   }
   else ({
-    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
+    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
     x_limits <- c(min(x_breaks), max(x_breaks))
     
     plot <- plot +
@@ -267,7 +267,7 @@ gg_hboxplot <- function(data,
 
 #' @title Horizontal boxplot ggplot that is coloured.
 #' @description Horizontal boxplot ggplot that is coloured, but not facetted.
-#' @param data An ungrouped summarised tibble or dataframe generally in a structure to be transformed to boxplot statistics (or alternatively in a structure of summary boxplot statistics). Required input.
+#' @param data An ungrouped summarised tibble or data frame generally in a structure to be transformed to boxplot statistics (or alternatively in a structure of summary boxplot statistics). Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale for when stat = "boxplot" is selected. 
 #' @param y_var Unquoted categorical variable to be on the y scale (i.e. character, factor, or logical). Required input.
 #' @param col_var Unquoted categorical or numeric variable to colour the boxplots. Required input.
@@ -277,14 +277,14 @@ gg_hboxplot <- function(data,
 #' @param alpha_fill The opacity of the fill. Defaults to 0.5. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param alpha_point The opacity of the outlier points. Defaults to 1. 
-#' @param size_line The size of the outlines of boxplots.
+#' @param size_line The size of the outlines of boxplots. Defaults to 0.5.
 #' @param size_point The size of the outlier points. Defaults to 1.5.
-#' @param size_width Width of boxes. Defaults to 0.5.
+#' @param width Width of boxes. Defaults to 0.5.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 60. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 60. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 2. 
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. Use ggplot2::waiver() to keep x labels untransformed.
@@ -338,7 +338,7 @@ gg_hboxplot <- function(data,
 #'   group_by(species, sex) %>% 
 #'   summarise_boxplot_outliers(body_mass_g)
 #' 
-#' size_width <- 0.5
+#' width <- 0.5
 #' 
 #' gg_hboxplot_col(plot_data,
 #'                xmin_var = min,
@@ -348,14 +348,14 @@ gg_hboxplot <- function(data,
 #'                xmax_var = max,
 #'                y_var = species,
 #'                col_var = sex,
-#'                size_width = size_width,
+#'                width = width,
 #'                stat = "identity",
 #'                x_title = "Body mass g",
 #'                x_breaks_n = 4, 
 #'                col_na_rm = TRUE) +
 #'                ggplot2::geom_point(ggplot2::aes(x = species, y = body_mass_g, col = sex), 
 #'                      size = 0.75, 
-#'                      position = ggplot2::position_dodge(width = size_width),
+#'                      position = ggplot2::position_dodge(width = width),
 #'                      data = outliers)
 #'                      
 gg_hboxplot_col <- function(data,
@@ -370,12 +370,12 @@ gg_hboxplot_col <- function(data,
                         alpha_point = 1,
                         size_line = 0.5,
                         size_point = 1.5,
-                        size_width = 0.5,
+                        width = 0.5,
                         title = NULL,
                         title_wrap = 75,
                         subtitle = NULL,
                         subtitle_wrap = 75,
-                        x_balance = FALSE,
+                        x_zero_mid = FALSE,
                         x_breaks_n = 5,
                         x_expand = c(0, 0),
                         x_labels = scales::label_comma(),
@@ -397,7 +397,7 @@ gg_hboxplot_col <- function(data,
                         col_title_wrap = 25,
                         caption = NULL,
                         caption_wrap = 75,
-                        theme = gg_theme(gridlines_v = TRUE),
+                        theme = gg_theme(x_grid = TRUE),
                         stat = "boxplot",
                         xmin_var = NULL,
                         xlower_var = NULL,
@@ -493,7 +493,7 @@ gg_hboxplot_col <- function(data,
   }
   else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  if (is.null(pal)) pal <- pal_d3_mix(col_n)
   else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -505,7 +505,7 @@ gg_hboxplot_col <- function(data,
   
   #fundamentals
   plot <- ggplot(data) +
-    coord_flip(clip = "off") +
+    coord_flip() +
     theme
   
   if (stat == "boxplot") {
@@ -515,7 +515,7 @@ gg_hboxplot_col <- function(data,
         position = position_dodge2(preserve = "single"),
         stat = stat,
         size = size_line, 
-        width = size_width,
+        width = width,
         outlier.alpha = alpha_point,
         outlier.size = size_point
       )
@@ -536,7 +536,7 @@ gg_hboxplot_col <- function(data,
         position = position_dodge2(preserve = "single"),
         stat = stat,
         size = size_line, 
-        width = size_width,
+        width = width,
         outlier.alpha = alpha_point,
         outlier.size = size_point
       )
@@ -547,7 +547,7 @@ gg_hboxplot_col <- function(data,
     scale_x_discrete(expand = y_expand, labels = y_labels)
 
   #x scale
-  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
   x_zero <- x_zero_list[[1]]
   x_zero_line <- x_zero_list[[2]]
   
@@ -556,7 +556,7 @@ gg_hboxplot_col <- function(data,
       scale_y_continuous(expand = x_expand, breaks = c(0, 1), labels = x_labels, limits = c(0, 1))
   }
   else ({
-    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
+    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
     x_limits <- c(min(x_breaks), max(x_breaks))
     
     plot <- plot +
@@ -588,19 +588,11 @@ gg_hboxplot_col <- function(data,
     ) 
   
   if (col_legend_none == FALSE) {
-    if (mobile == FALSE) {
-      plot <- plot +
-        guides(col = guide_legend(reverse = TRUE), fill = guide_legend(reverse = TRUE))
-    }
-    else if (mobile == TRUE) {
-      plot <- plot +
-        guides(col = guide_legend(ncol = 1, reverse = TRUE), fill = guide_legend(ncol = 1, reverse = TRUE))
-    }
-  }
-  
-  if (col_legend_none == TRUE) plot <- plot +
-    theme(legend.position = "none")
-  
+    plot <- plot +
+      guides(col = guide_legend(reverse = TRUE), 
+             fill = guide_legend(reverse = TRUE))
+  } 
+
   #titles
   if (mobile == FALSE) {
     plot <- plot +
@@ -624,12 +616,17 @@ gg_hboxplot_col <- function(data,
       theme_mobile_extra()
   }
   
+  if (col_legend_none == TRUE) {
+    plot <- plot +
+      theme(legend.position = "none")
+  }
+
   return(plot)
 }
 
 #' @title Horizontal boxplot ggplot that is facetted.
 #' @description Horizontal boxplot ggplot that is facetted, but not coloured.
-#' @param data An ungrouped summarised tibble or dataframe generally in a structure to be transformed to boxplot statistics (or alternatively in a structure of summary boxplot statistics). Required input.
+#' @param data An ungrouped summarised tibble or data frame generally in a structure to be transformed to boxplot statistics (or alternatively in a structure of summary boxplot statistics). Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale for when stat = "boxplot" is selected. 
 #' @param y_var Unquoted categorical variable to be on the y scale (i.e. character, factor, or logical). Required input.
 #' @param facet_var Unquoted categorical variable to facet the data by. Required input.
@@ -637,14 +634,14 @@ gg_hboxplot_col <- function(data,
 #' @param alpha_fill The opacity of the fill. Defaults to 0.5. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param alpha_point The opacity of the outlier points. Defaults to 1. 
-#' @param size_line The size of the outlines of boxplots. 
+#' @param size_line The size of the outlines of boxplots. Defaults to 0.5. 
 #' @param size_point The size of the outlier points. Defaults to 1.5.
-#' @param size_width Width of boxes. Defaults to 0.5.
+#' @param width Width of boxes. Defaults to 0.5.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 60. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 60. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 2. 
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. Use ggplot2::waiver() to keep x labels untransformed.
@@ -690,18 +687,18 @@ gg_hboxplot_facet <- function(data,
                           x_var = NULL,
                           y_var,
                           facet_var,
-                          pal = pal_viridis_reorder(1),
+                          pal = pal_viridis_mix(1),
                           alpha_fill = 0.5,
                           alpha_line = 1,
                           alpha_point = 1,
                           size_line = 0.5,
                           size_point = 1.5,
-                          size_width = 0.5,
+                          width = 0.5,
                           title = NULL,
                           title_wrap = 75,
                           subtitle = NULL,
                           subtitle_wrap = 75,
-                          x_balance = FALSE,
+                          x_zero_mid = FALSE,
                           x_breaks_n = 2,
                           x_expand = c(0, 0),
                           x_labels = scales::label_comma(),
@@ -723,7 +720,7 @@ gg_hboxplot_facet <- function(data,
                           facet_scales = "fixed",
                           caption = NULL,
                           caption_wrap = 75,
-                          theme = gg_theme(gridlines_v = TRUE),
+                          theme = gg_theme(x_grid = TRUE),
                           stat = "boxplot", 
                           xmin_var = NULL,
                           xlower_var = NULL,
@@ -817,7 +814,7 @@ gg_hboxplot_facet <- function(data,
   
   #fundamentals
   plot <- ggplot(data) +
-    coord_flip(clip = "off") +
+    coord_flip() +
     theme   
   
   if (stat == "boxplot") {
@@ -828,7 +825,7 @@ gg_hboxplot_facet <- function(data,
         fill = pal_fill,
         col = pal_line, 
         size = size_line, 
-        width = size_width,
+        width = width,
         outlier.alpha = alpha_point,
         outlier.size = size_point
       )
@@ -848,7 +845,7 @@ gg_hboxplot_facet <- function(data,
         fill = pal_fill,
         col = pal_line, 
         size = size_line, 
-        width = size_width,
+        width = width,
         outlier.alpha = alpha_point,
         outlier.size = size_point
       )
@@ -859,7 +856,7 @@ gg_hboxplot_facet <- function(data,
     scale_x_discrete(expand = y_expand, labels = y_labels)
 
   #x scale
-  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
   if (facet_scales %in% c("fixed", "free_y")) x_zero <- x_zero_list[[1]]
   x_zero_line <- x_zero_list[[2]]
   
@@ -869,7 +866,7 @@ gg_hboxplot_facet <- function(data,
         scale_y_continuous(expand = x_expand, breaks = c(0, 1), labels = x_labels, limits = c(0, 1))
     }
     else ({
-      x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
+      x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
       x_limits <- c(min(x_breaks), max(x_breaks))
       
       plot <- plot +
@@ -902,7 +899,7 @@ gg_hboxplot_facet <- function(data,
 
 #' @title Horizontal boxplot ggplot that is coloured and facetted.
 #' @description Horizontal boxplot ggplot that is coloured and facetted.
-#' @param data An ungrouped summarised tibble or dataframe generally in a structure to be transformed to boxplot statistics (or alternatively in a structure of summary boxplot statistics). Required input.
+#' @param data An ungrouped summarised tibble or data frame generally in a structure to be transformed to boxplot statistics (or alternatively in a structure of summary boxplot statistics). Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale for when stat = "boxplot" is selected. 
 #' @param y_var Unquoted categorical variable to be on the y scale (i.e. character, factor, or logical). Required input.
 #' @param col_var Unquoted categorical or numeric variable to colour the boxplots. Required input.
@@ -913,14 +910,14 @@ gg_hboxplot_facet <- function(data,
 #' @param alpha_fill The opacity of the fill. Defaults to 0.5. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param alpha_point The opacity of the outlier points. Defaults to 1. 
-#' @param size_width Width of boxes. Defaults to 0.5.
-#' @param size_line The size of the outlines of boxplots. 
+#' @param width Width of boxes. Defaults to 0.5.
+#' @param size_line The size of the outlines of boxplots. Defaults to 0.5. 
 #' @param size_point The size of the outlier points. Defaults to 1.5.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 60. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 60. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. Use ggplot2::waiver() to keep x labels untransformed.
 #' @param x_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5. 
@@ -985,13 +982,13 @@ gg_hboxplot_col_facet <- function(data,
                               alpha_point = 1,
                               size_line = 0.5,
                               size_point = 1.5,
-                              size_width = 0.5,
+                              width = 0.5,
                               title = NULL,
                               title_wrap = 75,
                               subtitle = NULL,
                               subtitle_wrap = 75,
                               x_breaks_n = 2,
-                              x_balance = FALSE,
+                              x_zero_mid = FALSE,
                               x_expand = c(0, 0),
                               x_labels = scales::label_comma(),
                               x_title = NULL,
@@ -1018,7 +1015,7 @@ gg_hboxplot_col_facet <- function(data,
                               facet_scales = "fixed",
                               caption = NULL,
                               caption_wrap = 75,
-                              theme = gg_theme(gridlines_v = TRUE), 
+                              theme = gg_theme(x_grid = TRUE), 
                               stat = "boxplot", 
                               xmin_var = NULL,
                               xlower_var = NULL,
@@ -1134,7 +1131,7 @@ gg_hboxplot_col_facet <- function(data,
   }
   else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  if (is.null(pal)) pal <- pal_d3_mix(col_n)
   else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -1146,7 +1143,7 @@ gg_hboxplot_col_facet <- function(data,
   
   #fundamentals
   plot <- ggplot(data) +
-    coord_flip(clip = "off") +
+    coord_flip() +
     theme 
   
   if (stat == "boxplot") {
@@ -1156,7 +1153,7 @@ gg_hboxplot_col_facet <- function(data,
         position = position_dodge2(preserve = "single"),
         stat = stat,
         size = size_line, 
-        width = size_width,
+        width = width,
         outlier.alpha = alpha_point,
         outlier.size = size_point
       )
@@ -1177,7 +1174,7 @@ gg_hboxplot_col_facet <- function(data,
         position = position_dodge2(preserve = "single"),
         stat = stat,
         size = size_line, 
-        width = size_width,
+        width = width,
         outlier.alpha = alpha_point,
         outlier.size = size_point
       )
@@ -1188,7 +1185,7 @@ gg_hboxplot_col_facet <- function(data,
     scale_x_discrete(expand = y_expand, labels = y_labels)
 
   #x scale
-  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
   if (facet_scales %in% c("fixed", "free_y")) x_zero <- x_zero_list[[1]]
   x_zero_line <- x_zero_list[[2]]
   
@@ -1198,7 +1195,7 @@ gg_hboxplot_col_facet <- function(data,
         scale_y_continuous(expand = x_expand, breaks = c(0, 1), labels = x_labels, limits = c(0, 1))
     }
     else ({
-      x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
+      x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
       x_limits <- c(min(x_breaks), max(x_breaks))
       
       plot <- plot +
@@ -1217,12 +1214,10 @@ gg_hboxplot_col_facet <- function(data,
   
   if (col_legend_none == FALSE) {
     plot <- plot +
-      guides(col = guide_legend(reverse = TRUE), fill = guide_legend(reverse = TRUE))
+      guides(col = guide_legend(reverse = TRUE), 
+             fill = guide_legend(reverse = TRUE))
   } 
   
-  if (col_legend_none == TRUE) plot <- plot +
-    theme(legend.position = "none")
-  
   #colour, titles & facetting
   plot <- plot +
     scale_colour_manual(
@@ -1248,5 +1243,10 @@ gg_hboxplot_col_facet <- function(data,
     ) +
     facet_wrap(vars(!!facet_var), labeller = as_labeller(facet_labels), scales = facet_scales, ncol = facet_ncol, nrow = facet_nrow)
   
+  if (col_legend_none == TRUE) {
+    plot <- plot +
+      theme(legend.position = "none")
+  }
+  
   return(plot)
 }
\ No newline at end of file
