@@ -1,6 +1,7 @@
 #' @title Smoothed ggplot.
+#' 
 #' @description Smoothed ggplot that is not coloured and not facetted.
-#' @param data An ungrouped summarised tibble or dataframe in a structure for points to be plotted untransformed, and a modelled line and ribbon to plotted based on this data. Required input.
+#' @param data A data frame in a structure for points to be plotted untransformed, and a modelled line and ribbon to plotted based on this data. Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale. Required input.
 #' @param y_var Unquoted numeric variable to be on the y scale. Required input.
 #' @param pal Character vector of hex codes. 
@@ -13,7 +14,7 @@
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. Not applicable where mobile equals TRUE.
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5. 
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. Use ggplot2::waiver() to keep x labels untransformed.
@@ -21,7 +22,7 @@
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
 #' @param x_zero For a numeric x variable, TRUE or FALSE of whether the minimum of the x scale is zero. Defaults to FALSE.
 #' @param x_zero_line For a numeric x variable, TRUE or FALSE of whether to add a zero reference line to the x scale. Defaults to TRUE if there are positive and negative values in x_var. Otherwise defaults to FALSE.   
-#' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
+#' @param y_zero_mid For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5. 
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. Use ggplot2::waiver() to keep y labels untransformed.
@@ -53,7 +54,7 @@
 gg_smooth <- function(data,
                       x_var,
                       y_var,
-                      pal = pal_viridis_reorder(1),
+                      pal = pal_viridis_mix(1),
                       alpha_fill = 0.5, 
                       alpha_line = 1,
                       alpha_point = 1,
@@ -63,7 +64,7 @@ gg_smooth <- function(data,
                       title_wrap = 80,
                       subtitle = NULL,
                       subtitle_wrap = 80,
-                      x_balance = FALSE,
+                      x_zero_mid = FALSE,
                       x_breaks_n = 5,
                       x_expand = NULL,
                       x_labels = scales::label_comma(),
@@ -71,7 +72,7 @@ gg_smooth <- function(data,
                       x_title_wrap = 50,
                       x_zero = FALSE,
                       x_zero_line = NULL,
-                      y_balance = FALSE,
+                      y_zero_mid = FALSE,
                       y_breaks_n = 5,
                       y_expand = c(0, 0),
                       y_labels = scales::label_comma(),
@@ -81,7 +82,7 @@ gg_smooth <- function(data,
                       y_zero_line = NULL,
                       caption = NULL,
                       caption_wrap = 80,
-                      theme = gg_theme(gridlines_h = TRUE, gridlines_v = TRUE),
+                      theme = gg_theme(y_grid = TRUE, x_grid = TRUE),
                       model_method = NULL,
                       model_formula = NULL,
                       model_se = TRUE,
@@ -122,7 +123,7 @@ gg_smooth <- function(data,
   #fundamentals
   plot <- ggplot(data) +
     theme +
-    coord_cartesian(clip = "off") +
+    coord_cartesian() +
     geom_point(aes(!!x_var, !!y_var), col = pal_point, size = size_point) + 
     geom_smooth(aes(!!x_var, !!y_var),
                 col = pal_line, 
@@ -133,10 +134,10 @@ gg_smooth <- function(data,
                 method = model_method, formula = model_formula, span = model_span, n = model_n) 
   
   #x scale  
-  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
   x_zero <- x_zero_list[[1]]
   x_zero_line <- x_zero_list[[2]]
-  x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
+  x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
   x_limits <- c(min(x_breaks), max(x_breaks))
   if (is.null(x_expand)) x_expand <- c(0, 0)
   
@@ -154,7 +155,7 @@ gg_smooth <- function(data,
   }
   
   #y scale
-  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_balance = y_balance, y_zero = y_zero, y_zero_line = y_zero_line)
+  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_zero_mid = y_zero_mid, y_zero = y_zero, y_zero_line = y_zero_line)
   y_zero <- y_zero_list[[1]]
   y_zero_line <- y_zero_list[[2]]
   
@@ -163,7 +164,7 @@ gg_smooth <- function(data,
       scale_y_continuous(expand = y_expand, breaks = c(0, 1), labels = y_labels, limits = c(0, 1))
   }
   else ({
-    y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_balance, breaks_n = y_breaks_n, zero = y_zero)
+    y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_zero_mid, breaks_n = y_breaks_n, zero = y_zero)
     y_limits <- c(min(y_breaks), max(y_breaks))
     
     plot <- plot +
@@ -202,8 +203,9 @@ gg_smooth <- function(data,
 }
 
 #' @title Smoothed ggplot that is coloured.
+#' 
 #' @description Smoothed ggplot that is coloured, but not facetted.
-#' @param data An ungrouped summarised tibble or dataframe in a structure for points to be plotted untransformed, and a modelled line and ribbon to plotted based on this data. Required input.
+#' @param data A data frame in a structure for points to be plotted untransformed, and a modelled line and ribbon to plotted based on this data. Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale. Required input.
 #' @param y_var Unquoted numeric variable to be on the y scale. Required input.
 #' @param col_var Unquoted categorical variable for points to be coloured by. Required input.
@@ -219,7 +221,7 @@ gg_smooth <- function(data,
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. Not applicable where mobile equals TRUE.
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. Use ggplot2::waiver() to keep x labels untransformed.
 #' @param x_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5. 
@@ -227,7 +229,7 @@ gg_smooth <- function(data,
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
 #' @param x_zero For a numeric x variable, TRUE or FALSE of whether the minimum of the x scale is zero. Defaults to FALSE.
 #' @param x_zero_line For a numeric x variable, TRUE or FALSE of whether to add a zero reference line to the x scale. Defaults to TRUE if there are positive and negative values in x_var. Otherwise defaults to FALSE.   
-#' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
+#' @param y_zero_mid For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. Use ggplot2::waiver() to keep y labels untransformed.
 #' @param y_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5. 
@@ -261,8 +263,6 @@ gg_smooth <- function(data,
 #'              y_var = body_mass_g, 
 #'              col_var = species)
 #'              
-#' #if ggplotly legend bug, pipe in plotly::style(showlegend = FALSE, traces = x:y) layer 
-#' 
 gg_smooth_col <- function(data,
                           x_var,
                           y_var,
@@ -279,7 +279,7 @@ gg_smooth_col <- function(data,
                           title_wrap = 80,
                           subtitle = NULL,
                           subtitle_wrap = 80,
-                          x_balance = FALSE,
+                          x_zero_mid = FALSE,
                           x_breaks_n = 5,
                           x_expand = NULL,
                           x_labels = scales::label_comma(),
@@ -287,7 +287,7 @@ gg_smooth_col <- function(data,
                           x_title_wrap = 50,
                           x_zero = FALSE,
                           x_zero_line = NULL,
-                          y_balance = FALSE,
+                          y_zero_mid = FALSE,
                           y_breaks_n = 5,
                           y_expand = c(0, 0),
                           y_labels = scales::label_comma(),
@@ -302,7 +302,7 @@ gg_smooth_col <- function(data,
                           col_title_wrap = 25,
                           caption = NULL,
                           caption_wrap = 80,
-                          theme = gg_theme(gridlines_h = TRUE, gridlines_v = TRUE),
+                          theme = gg_theme(y_grid = TRUE, x_grid = TRUE),
                           model_method = NULL,
                           model_formula = NULL,
                           model_se = TRUE,
@@ -357,7 +357,7 @@ gg_smooth_col <- function(data,
   }
   else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  if (is.null(pal)) pal <- pal_d3_mix(col_n)
   else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -370,7 +370,7 @@ gg_smooth_col <- function(data,
   #fundamentals
   plot <- ggplot(data) +
     theme +
-    coord_cartesian(clip = "off") +
+    coord_cartesian() +
     geom_point(aes(!!x_var, !!y_var, col = !!col_var), alpha = alpha_point, size = size_point, show.legend = FALSE) + 
     geom_smooth(aes(!!x_var, !!y_var, col = !!col_var, fill = !!col_var),
                 alpha = alpha_fill,
@@ -379,10 +379,10 @@ gg_smooth_col <- function(data,
                 method = model_method, formula = model_formula, span = model_span, n = model_n) 
   
   #x scale  
-  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+  x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
   x_zero <- x_zero_list[[1]]
   x_zero_line <- x_zero_list[[2]]
-  x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
+  x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = mobile)
   x_limits <- c(min(x_breaks), max(x_breaks))
   if (is.null(x_expand)) x_expand <- c(0, 0)
   
@@ -400,7 +400,7 @@ gg_smooth_col <- function(data,
   }
   
   #y scale
-  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_balance = y_balance, y_zero = y_zero, y_zero_line = y_zero_line)
+  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_zero_mid = y_zero_mid, y_zero = y_zero, y_zero_line = y_zero_line)
   y_zero <- y_zero_list[[1]]
   y_zero_line <- y_zero_list[[2]]
   
@@ -409,7 +409,7 @@ gg_smooth_col <- function(data,
       scale_y_continuous(expand = y_expand, breaks = c(0, 1), labels = y_labels, limits = c(0, 1))
   }
   else ({
-    y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_balance, breaks_n = y_breaks_n, zero = y_zero)
+    y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_zero_mid, breaks_n = y_breaks_n, zero = y_zero)
     y_limits <- c(min(y_breaks), max(y_breaks))
     
     plot <- plot +
@@ -440,15 +440,6 @@ gg_smooth_col <- function(data,
       name = stringr::str_wrap(col_title, col_title_wrap)
     )
   
-  if (mobile == TRUE & col_legend_none == TRUE) {
-    plot <- plot +
-      guides(col = guide_legend(ncol = 1),
-             fill = guide_legend(ncol = 1))
-  }
-  
-  if (col_legend_none == TRUE) plot <- plot +
-    theme(legend.position = "none")
-  
   #titles
   if (mobile == FALSE) {
     plot <- plot +
@@ -472,12 +463,18 @@ gg_smooth_col <- function(data,
       theme_mobile_extra() #extra mobile theme components
   }
   
+  if (col_legend_none == TRUE) {
+    plot <- plot +
+      theme(legend.position = "none")
+  }
+
   return(plot)
 }
 
 #' @title Smoothed ggplot that is facetted.
+#' 
 #' @description Smoothed ggplot that is facetted, but not coloured.
-#' @param data An ungrouped summarised tibble or dataframe in a structure for points to be plotted untransformed, and a modelled line and ribbon to plotted based on this data. Required input.
+#' @param data A data frame in a structure for points to be plotted untransformed, and a modelled line and ribbon to plotted based on this data. Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale. Required input.
 #' @param y_var Unquoted numeric variable to be on the y scale. Required input.
 #' @param facet_var Unquoted categorical variable to facet the data by. Required input.
@@ -491,7 +488,7 @@ gg_smooth_col <- function(data,
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. Use ggplot2::waiver() to keep x labels untransformed.
 #' @param x_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 2. 
@@ -499,7 +496,7 @@ gg_smooth_col <- function(data,
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
 #' @param x_zero For a numeric x variable, TRUE or FALSE of whether the minimum of the x scale is zero. Defaults to FALSE.
 #' @param x_zero_line For a numeric x variable, TRUE or FALSE of whether to add a zero reference line to the x scale. Defaults to TRUE if there are positive and negative values in x_var. Otherwise defaults to FALSE.   
-#' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
+#' @param y_zero_mid For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. Use ggplot2::waiver() to keep y labels untransformed.
 #' @param y_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 4. 
@@ -538,7 +535,7 @@ gg_smooth_facet <- function(data,
                             x_var,
                             y_var,
                             facet_var,
-                            pal = pal_viridis_reorder(1),
+                            pal = pal_viridis_mix(1),
                             alpha_fill = 0.5, 
                             alpha_line = 1,
                             alpha_point = 1,
@@ -548,7 +545,7 @@ gg_smooth_facet <- function(data,
                             title_wrap = 80,
                             subtitle = NULL,
                             subtitle_wrap = 80,
-                            x_balance = FALSE,
+                            x_zero_mid = FALSE,
                             x_breaks_n = 2,
                             x_expand = NULL,
                             x_labels = scales::label_comma(),
@@ -556,7 +553,7 @@ gg_smooth_facet <- function(data,
                             x_title_wrap = 50,
                             x_zero = FALSE,
                             x_zero_line = NULL,
-                            y_balance = FALSE,
+                            y_zero_mid = FALSE,
                             y_breaks_n = 3,
                             y_expand = c(0, 0),
                             y_labels = scales::label_comma(),
@@ -572,7 +569,7 @@ gg_smooth_facet <- function(data,
                             facet_scales = "fixed",
                             caption = NULL,
                             caption_wrap = 80,
-                            theme = gg_theme(gridlines_h = TRUE, gridlines_v = TRUE), 
+                            theme = gg_theme(y_grid = TRUE, x_grid = TRUE), 
                             model_method = NULL,
                             model_formula = NULL,
                             model_se = TRUE,
@@ -636,7 +633,7 @@ gg_smooth_facet <- function(data,
   #fundamentals
   plot <- ggplot(data) +
     theme +
-    coord_cartesian(clip = "off") +
+    coord_cartesian() +
     geom_point(aes(!!x_var, !!y_var), col = pal_point, alpha = alpha_point, size = size_point) + 
     geom_smooth(aes(!!x_var, !!y_var),
                 col = pal_line, 
@@ -648,10 +645,10 @@ gg_smooth_facet <- function(data,
   
   #x scale
   if (facet_scales %in% c("fixed", "free_y")) {
-    x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+    x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
     x_zero <- x_zero_list[[1]]
     x_zero_line <- x_zero_list[[2]]
-    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
+    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
     x_limits <- c(min(x_breaks), max(x_breaks))
     if (is.null(x_expand)) x_expand <- c(0, 0)
     
@@ -665,7 +662,7 @@ gg_smooth_facet <- function(data,
   }
   
   #y scale
-  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_balance = y_balance, y_zero = y_zero, y_zero_line = y_zero_line)
+  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_zero_mid = y_zero_mid, y_zero = y_zero, y_zero_line = y_zero_line)
   if (facet_scales %in% c("fixed", "free_x")) y_zero <- y_zero_list[[1]]
   y_zero_line <- y_zero_list[[2]]
   
@@ -675,7 +672,7 @@ gg_smooth_facet <- function(data,
         scale_y_continuous(expand = y_expand, breaks = c(0, 1), labels = y_labels, limits = c(0, 1))
     }
     else ({
-      y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_balance, breaks_n = y_breaks_n, zero = y_zero)
+      y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_zero_mid, breaks_n = y_breaks_n, zero = y_zero)
       y_limits <- c(min(y_breaks), max(y_breaks))
       
       plot <- plot +
@@ -707,8 +704,9 @@ gg_smooth_facet <- function(data,
 }
 
 #' @title Smoothed ggplot that is coloured and facetted.
+#' 
 #' @description Smoothed ggplot that is coloured and facetted.
-#' @param data An ungrouped summarised tibble or dataframe in a structure for points to be plotted untransformed, and a modelled line and ribbon to plotted based on this data. Required input.
+#' @param data A data frame in a structure for points to be plotted untransformed, and a modelled line and ribbon to plotted based on this data. Required input.
 #' @param x_var Unquoted numeric variable to be on the x scale. Required input.
 #' @param y_var Unquoted numeric variable to be on the y scale. Required input.
 #' @param col_var Unquoted categorical variable for points to be coloured by. Required input.
@@ -725,7 +723,7 @@ gg_smooth_facet <- function(data,
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
-#' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
+#' @param x_zero_mid For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 2. 
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. Use ggplot2::waiver() to keep x labels untransformed.
@@ -733,7 +731,7 @@ gg_smooth_facet <- function(data,
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
 #' @param x_zero For a numeric x variable, TRUE or FALSE of whether the minimum of the x scale is zero. Defaults to FALSE.
 #' @param x_zero_line For a numeric x variable, TRUE or FALSE of whether to add a zero reference line to the x scale. Defaults to TRUE if there are positive and negative values in x_var. Otherwise defaults to FALSE.   
-#' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
+#' @param y_zero_mid For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 4. 
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. Use ggplot2::waiver() to keep y labels untransformed.
@@ -775,7 +773,6 @@ gg_smooth_facet <- function(data,
 #'                    facet_var = species, 
 #'                    col_na_rm = TRUE)
 #' 
-#' #if ggplotly legend bug, pipe in plotly::style(showlegend = FALSE, traces = x:y) layer 
 #' 
 gg_smooth_col_facet <- function(data,
                                 x_var,
@@ -794,7 +791,7 @@ gg_smooth_col_facet <- function(data,
                                 title_wrap = 80,
                                 subtitle = NULL,
                                 subtitle_wrap = 80,
-                                x_balance = FALSE,
+                                x_zero_mid = FALSE,
                                 x_breaks_n = 2,
                                 x_expand = NULL,
                                 x_labels = scales::label_comma(),
@@ -802,7 +799,7 @@ gg_smooth_col_facet <- function(data,
                                 x_title_wrap = 50,
                                 x_zero = FALSE,
                                 x_zero_line = NULL,
-                                y_balance = FALSE,
+                                y_zero_mid = FALSE,
                                 y_breaks_n = 3,
                                 y_expand = c(0, 0),
                                 y_labels = scales::label_comma(),
@@ -823,7 +820,7 @@ gg_smooth_col_facet <- function(data,
                                 facet_scales = "fixed",
                                 caption = NULL,
                                 caption_wrap = 80,
-                                theme = gg_theme(gridlines_h = TRUE, gridlines_v = TRUE), 
+                                theme = gg_theme(y_grid = TRUE, x_grid = TRUE), 
                                 model_method = NULL,
                                 model_formula = NULL,
                                 model_se = TRUE,
@@ -898,7 +895,7 @@ gg_smooth_col_facet <- function(data,
   }
   else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  if (is.null(pal)) pal <- pal_d3_mix(col_n)
   else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -911,7 +908,7 @@ gg_smooth_col_facet <- function(data,
   #fundamentals
   plot <- ggplot(data) +
     theme +
-    coord_cartesian(clip = "off") +
+    coord_cartesian() +
     geom_point(aes(!!x_var, !!y_var, col = !!col_var), alpha = alpha_point, size = size_point, show.legend = FALSE) +
     geom_smooth(aes(!!x_var, !!y_var, col = !!col_var, fill = !!col_var),
                 alpha = alpha_fill,
@@ -921,10 +918,10 @@ gg_smooth_col_facet <- function(data,
   
   #x scale
   if (facet_scales %in% c("fixed", "free_y")) {
-    x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_balance = x_balance, x_zero = x_zero, x_zero_line = x_zero_line)
+    x_zero_list <- sv_x_zero_adjust(x_var_vctr, x_zero_mid = x_zero_mid, x_zero = x_zero, x_zero_line = x_zero_line)
     x_zero <- x_zero_list[[1]]
     x_zero_line <- x_zero_list[[2]]
-    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_balance, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
+    x_breaks <- sv_numeric_breaks_h(x_var_vctr, balance = x_zero_mid, breaks_n = x_breaks_n, zero = x_zero, mobile = FALSE)
     x_limits <- c(min(x_breaks), max(x_breaks))
     if (is.null(x_expand)) x_expand <- c(0, 0)
     
@@ -938,7 +935,7 @@ gg_smooth_col_facet <- function(data,
   }
   
   #y scale
-  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_balance = y_balance, y_zero = y_zero, y_zero_line = y_zero_line)
+  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_zero_mid = y_zero_mid, y_zero = y_zero, y_zero_line = y_zero_line)
   if (facet_scales %in% c("fixed", "free_x")) y_zero <- y_zero_list[[1]]
   y_zero_line <- y_zero_list[[2]]
   
@@ -948,7 +945,7 @@ gg_smooth_col_facet <- function(data,
         scale_y_continuous(expand = y_expand, breaks = c(0, 1), labels = y_labels, limits = c(0, 1))
     }
     else ({
-      y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_balance, breaks_n = y_breaks_n, zero = y_zero)
+      y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_zero_mid, breaks_n = y_breaks_n, zero = y_zero)
       y_limits <- c(min(y_breaks), max(y_breaks))
       
       plot <- plot +
@@ -966,9 +963,6 @@ gg_smooth_col_facet <- function(data,
   }
   
   #colour, titles & facetting
-  if (col_legend_none == TRUE) plot <- plot +
-    theme(legend.position = "none")
-  
   plot <- plot +
     scale_colour_manual(
       values = pal_line,
@@ -993,6 +987,10 @@ gg_smooth_col_facet <- function(data,
     ) +
     facet_wrap(vars(!!facet_var), labeller = as_labeller(facet_labels), scales = facet_scales, ncol = facet_ncol, nrow = facet_nrow)
   
-  
+  if (col_legend_none == TRUE) {
+    plot <- plot +
+      theme(legend.position = "none")
+  }
+
   return(plot)
 }
