@@ -1,13 +1,14 @@
 #' @title Violin ggplot.
+#' 
 #' @description Violin ggplot that is not coloured and not facetted.
-#' @param data An ungrouped summarised tibble or dataframe in a structure to be transformed to density statistics. Required input.
+#' @param data A data frame in a structure to be transformed to density statistics. Required input.
 #' @param x_var Unquoted categorical variable to be on the x scale (i.e. character, factor, logical). Required input.
 #' @param y_var Generally an unquoted numeric variable to be on the y scale. 
 #' @param pal Character vector of hex codes. 
 #' @param alpha_fill The opacity of the fill. Defaults to 1. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param size_line The size of the outlines of violins. Defaults to 0.5.
-#' @param size_width Width of boxes. Defaults to 0.75.
+#' @param width Width of boxes. Defaults to 0.75.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
@@ -18,7 +19,7 @@
 #' @param x_rev For a categorical x variable, TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
-#' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
+#' @param y_zero_mid For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5.
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions.
 #' @param y_labels A function or named vector to modify y scale labels. Use ggplot2::waiver() to keep y labels untransformed.
@@ -48,11 +49,11 @@
 gg_violin <- function(data,
                       x_var,
                       y_var = NULL,
-                      pal = pal_viridis_reorder(1),
+                      pal = pal_viridis_mix(1),
                       alpha_fill = 1,
                       alpha_line = 1,
                       size_line = 0.5,
-                      size_width = 0.75,
+                      width = 0.75,
                       title = NULL,
                       title_wrap = 80,
                       subtitle = NULL,
@@ -63,7 +64,7 @@ gg_violin <- function(data,
                       x_rev = FALSE,
                       x_title = NULL,
                       x_title_wrap = 50,
-                      y_balance = FALSE,
+                      y_zero_mid = FALSE,
                       y_breaks_n = 5,
                       y_expand = c(0, 0),
                       y_labels = scales::label_comma(),
@@ -73,7 +74,7 @@ gg_violin <- function(data,
                       y_zero_line = NULL,
                       caption = NULL,
                       caption_wrap = 80,
-                      theme = gg_theme(gridlines_h = TRUE),
+                      theme = gg_theme(y_grid = TRUE),
                       model_scale = "area",
                       model_bw = "nrd0",
                       model_adjust = 1,
@@ -131,7 +132,7 @@ gg_violin <- function(data,
 
   #fundamentals
   plot <- ggplot(data) +
-    coord_cartesian(clip = "off") +
+    coord_cartesian() +
     theme
   
   plot <- plot +
@@ -141,7 +142,7 @@ gg_violin <- function(data,
       fill = pal_fill,
       col = pal_line, 
       size = size_line, 
-      width = size_width,
+      width = width,
     )
     
   #x scale 
@@ -149,7 +150,7 @@ gg_violin <- function(data,
     scale_x_discrete(expand = x_expand, labels = x_labels)
   
   #y scale
-  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_balance = y_balance, y_zero = y_zero, y_zero_line = y_zero_line)
+  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_zero_mid = y_zero_mid, y_zero = y_zero, y_zero_line = y_zero_line)
   y_zero <- y_zero_list[[1]]
   y_zero_line <- y_zero_list[[2]]
   
@@ -158,7 +159,7 @@ gg_violin <- function(data,
       scale_y_continuous(expand = y_expand, breaks = c(0, 1), labels = y_labels, limits = c(0, 1))
   }
   else ({
-    y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_balance, breaks_n = y_breaks_n, zero = y_zero)
+    y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_zero_mid, breaks_n = y_breaks_n, zero = y_zero)
     y_limits <- c(min(y_breaks), max(y_breaks))
     
     plot <- plot +
@@ -196,9 +197,10 @@ gg_violin <- function(data,
   return(plot)
 }
 
-#' Violin ggplot that is coloured
-#'
-#' @param data An ungrouped summarised tibble or dataframe in a structure to be transformed to density statistics. Required input.
+#' @title Violin ggplot that is coloured.
+#' 
+#' @description Violin ggplot that is coloured, but not facetted.
+#' @param data A data frame in a structure to be transformed to density statistics. Required input.
 #' @param x_var Unquoted categorical variable to be on the x scale (i.e. character, factor, logical). Required input.
 #' @param y_var Generally an unquoted numeric variable to be on the y scale. 
 #' @param col_var Unquoted categorical variable to colour the fill of the boxes. Required input.
@@ -208,7 +210,7 @@ gg_violin <- function(data,
 #' @param alpha_fill The opacity of the fill. Defaults to 1. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param size_line The size of the outlines of violins. Defaults to 0.5.
-#' @param size_width Width of boxes. Defaults to 0.75.
+#' @param width Width of boxes. Defaults to 0.75.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
@@ -219,7 +221,7 @@ gg_violin <- function(data,
 #' @param x_rev For a categorical x variable, TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
-#' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
+#' @param y_zero_mid For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5.
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. Use ggplot2::waiver() to keep y labels untransformed.
@@ -266,7 +268,7 @@ gg_violin_col <- function(data,
                           alpha_fill = 1,
                           alpha_line = 1,
                           size_line = 0.5,
-                          size_width = 0.75,
+                          width = 0.75,
                           title = NULL,
                           title_wrap = 80,
                           subtitle = NULL,
@@ -277,7 +279,7 @@ gg_violin_col <- function(data,
                           x_rev = FALSE,
                           x_title = NULL,
                           x_title_wrap = 50,
-                          y_balance = FALSE,
+                          y_zero_mid = FALSE,
                           y_expand = c(0, 0),
                           y_labels = scales::label_comma(),
                           y_breaks_n = 5,
@@ -293,7 +295,7 @@ gg_violin_col <- function(data,
                           col_title_wrap = 25,
                           caption = NULL,
                           caption_wrap = 80,
-                          theme = gg_theme(gridlines_h = TRUE),
+                          theme = gg_theme(y_grid = TRUE),
                           model_scale = "area",
                           model_bw = "nrd0",
                           model_adjust = 1,
@@ -371,7 +373,7 @@ gg_violin_col <- function(data,
   }
   else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  if (is.null(pal)) pal <- pal_d3_mix(col_n)
   else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -383,13 +385,13 @@ gg_violin_col <- function(data,
   
   #fundamentals
   plot <- ggplot(data) +
-    coord_cartesian(clip = "off") +
+    coord_cartesian() +
     theme +
     geom_violin(
       aes(x = !!x_var, y = !!y_var, col = !!col_var, fill = !!col_var), 
       scale = model_scale, bw = model_bw, adjust = model_adjust, kernel = model_kernel, trim = model_trim,
       size = size_line, 
-      width = size_width
+      width = width
     )
 
   #x scale 
@@ -397,7 +399,7 @@ gg_violin_col <- function(data,
     scale_x_discrete(expand = x_expand, labels = x_labels)
   
   #y scale
-  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_balance = y_balance, y_zero = y_zero, y_zero_line = y_zero_line)
+  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_zero_mid = y_zero_mid, y_zero = y_zero, y_zero_line = y_zero_line)
   y_zero <- y_zero_list[[1]]
   y_zero_line <- y_zero_list[[2]]
   
@@ -406,7 +408,7 @@ gg_violin_col <- function(data,
       scale_y_continuous(expand = y_expand, breaks = c(0, 1), labels = y_labels, limits = c(0, 1))
   }
   else ({
-    y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_balance, breaks_n = y_breaks_n, zero = y_zero)
+    y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_zero_mid, breaks_n = y_breaks_n, zero = y_zero)
     y_limits <- c(min(y_breaks), max(y_breaks))
     
     plot <- plot +
@@ -437,14 +439,6 @@ gg_violin_col <- function(data,
       name = stringr::str_wrap(col_title, col_title_wrap)
     ) 
   
-  if (mobile == TRUE & col_legend_none == TRUE) {
-    plot <- plot +
-      guides(col = guide_legend(ncol = 1), fill = guide_legend(ncol = 1))
-  }
-  
-  if (col_legend_none == TRUE) plot <- plot +
-    theme(legend.position = "none")
-  
   #titles
   if (mobile == FALSE) {
     plot <- plot +
@@ -468,12 +462,18 @@ gg_violin_col <- function(data,
       theme_mobile_extra() 
   }
   
+  if (col_legend_none == TRUE) {
+    plot <- plot +
+      theme(legend.position = "none")
+  }
+
   return(plot)
 }
 
 #' @title Violin ggplot that is facetted.
+#' 
 #' @description Violin ggplot that is facetted, but not coloured.
-#' @param data An tibble or dataframe. Required input.
+#' @param data An tibble or data frame. Required input.
 #' @param x_var Unquoted categorical variable to be on the x scale (i.e. character, factor, logical). Required input.
 #' @param y_var Generally an unquoted numeric variable to be on the y scale. 
 #' @param facet_var Unquoted categorical variable to facet the data by. Required input.
@@ -481,7 +481,7 @@ gg_violin_col <- function(data,
 #' @param alpha_fill The opacity of the fill. Defaults to 1. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param size_line The size of the outlines of violins. Defaults to 0.5.
-#' @param size_width Width of boxes. Defaults to 0.75.
+#' @param width Width of boxes. Defaults to 0.75.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
@@ -492,7 +492,7 @@ gg_violin_col <- function(data,
 #' @param x_rev For a categorical x variable, TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
-#' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
+#' @param y_zero_mid For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 4.
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. Use ggplot2::waiver() to keep y labels untransformed.
@@ -532,11 +532,11 @@ gg_violin_facet <- function(data,
                             x_var,
                             y_var = NULL,
                             facet_var,
-                            pal = pal_viridis_reorder(1),
+                            pal = pal_viridis_mix(1),
                             alpha_fill = 1,
                             alpha_line = 1,
                             size_line = 0.5,
-                            size_width = 0.75,
+                            width = 0.75,
                             title = NULL,
                             title_wrap = 80,
                             subtitle = NULL,
@@ -547,7 +547,7 @@ gg_violin_facet <- function(data,
                             x_rev = FALSE,
                             x_title = NULL,
                             x_title_wrap = 50,
-                            y_balance = FALSE,
+                            y_zero_mid = FALSE,
                             y_breaks_n = 3,
                             y_expand = c(0, 0),
                             y_labels = scales::label_comma(),
@@ -563,7 +563,7 @@ gg_violin_facet <- function(data,
                             facet_scales = "fixed",
                             caption = NULL,
                             caption_wrap = 80,
-                            theme = gg_theme(gridlines_h = TRUE),  
+                            theme = gg_theme(y_grid = TRUE),  
                             model_scale = "area",
                             model_bw = "nrd0",
                             model_adjust = 1,
@@ -640,7 +640,7 @@ gg_violin_facet <- function(data,
 
   #fundamentals
   plot <- ggplot(data) +
-    coord_cartesian(clip = "off") +
+    coord_cartesian() +
     theme +
     geom_violin(
       aes(x = !!x_var, y = !!y_var), 
@@ -648,7 +648,7 @@ gg_violin_facet <- function(data,
       fill = pal_fill,
       col = pal_line, 
       size = size_line, 
-      width = size_width
+      width = width
     )
 
   #x scale 
@@ -656,7 +656,7 @@ gg_violin_facet <- function(data,
     scale_x_discrete(expand = x_expand, labels = x_labels)
   
   #y scale
-  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_balance = y_balance, y_zero = y_zero, y_zero_line = y_zero_line)
+  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_zero_mid = y_zero_mid, y_zero = y_zero, y_zero_line = y_zero_line)
   if (facet_scales %in% c("fixed", "free_x")) y_zero <- y_zero_list[[1]]
   y_zero_line <- y_zero_list[[2]]
   
@@ -666,7 +666,7 @@ gg_violin_facet <- function(data,
         scale_y_continuous(expand = y_expand, breaks = c(0, 1), labels = y_labels, limits = c(0, 1))
     }
     else ({
-      y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_balance, breaks_n = y_breaks_n, zero = y_zero)
+      y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_zero_mid, breaks_n = y_breaks_n, zero = y_zero)
       y_limits <- c(min(y_breaks), max(y_breaks))
       
       plot <- plot +
@@ -697,9 +697,10 @@ gg_violin_facet <- function(data,
   return(plot)
 }
 
-#' Violin ggplot that is coloured and facetted.
-#'
-#' @param data An ungrouped summarised tibble or dataframe in a structure to be transformed to density statistics. Required input.
+#' @title Violin ggplot that is coloured and facetted.
+#' 
+#' @description Violin ggplot that is coloured and facetted.
+#' @param data A data frame in a structure to be transformed to density statistics. Required input.
 #' @param x_var Unquoted categorical variable to be on the x scale (i.e. character, factor, logical). Required input.
 #' @param y_var Generally an unquoted numeric variable to be on the y scale. 
 #' @param col_var Unquoted categorical variable to colour the fill of the boxes. Required input.
@@ -710,7 +711,7 @@ gg_violin_facet <- function(data,
 #' @param alpha_fill The opacity of the fill. Defaults to 1. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param size_line The size of the outlines of violins. Defaults to 0.5.
-#' @param size_width Width of boxes. Defaults to 0.75.
+#' @param width Width of boxes. Defaults to 0.75.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
@@ -721,7 +722,7 @@ gg_violin_facet <- function(data,
 #' @param x_rev For a categorical x variable, TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
-#' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
+#' @param y_zero_mid For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_breaks_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 4. 
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. Use ggplot2::waiver() to keep y labels untransformed.
@@ -777,7 +778,7 @@ gg_violin_col_facet <- function(data,
                                 alpha_fill = 1,
                                 alpha_line = 1,
                                 size_line = 0.5,
-                                size_width = 0.75,
+                                width = 0.75,
                                 title = NULL,
                                 title_wrap = 80,
                                 subtitle = NULL,
@@ -788,7 +789,7 @@ gg_violin_col_facet <- function(data,
                                 x_rev = FALSE,
                                 x_title = NULL,
                                 x_title_wrap = 50,
-                                y_balance = FALSE,
+                                y_zero_mid = FALSE,
                                 y_breaks_n = 3,
                                 y_expand = c(0, 0),
                                 y_labels = scales::label_comma(),
@@ -810,7 +811,7 @@ gg_violin_col_facet <- function(data,
                                 facet_scales = "fixed",
                                 caption = NULL,
                                 caption_wrap = 80,
-                                theme = gg_theme(gridlines_h = TRUE),
+                                theme = gg_theme(y_grid = TRUE),
                                 model_scale = "area",
                                 model_bw = "nrd0",
                                 model_adjust = 1,
@@ -907,7 +908,7 @@ gg_violin_col_facet <- function(data,
   }
   else col_n <- length(unique(col_var_vctr))
   
-  if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+  if (is.null(pal)) pal <- pal_d3_mix(col_n)
   else pal <- pal[1:col_n]
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -919,13 +920,13 @@ gg_violin_col_facet <- function(data,
   
   #fundamentals
   plot <- ggplot(data) +
-    coord_cartesian(clip = "off") +
+    coord_cartesian() +
     theme +
     geom_violin(
       aes(x = !!x_var, y = !!y_var, col = !!col_var, fill = !!col_var), 
       scale = model_scale, bw = model_bw, adjust = model_adjust, kernel = model_kernel, trim = model_trim,
       size = size_line, 
-      width = size_width
+      width = width
     )
 
   #x scale 
@@ -933,7 +934,7 @@ gg_violin_col_facet <- function(data,
     scale_x_discrete(expand = x_expand, labels = x_labels)
   
   #y scale
-  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_balance = y_balance, y_zero = y_zero, y_zero_line = y_zero_line)
+  y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_zero_mid = y_zero_mid, y_zero = y_zero, y_zero_line = y_zero_line)
   if (facet_scales %in% c("fixed", "free_x")) y_zero <- y_zero_list[[1]]
   y_zero_line <- y_zero_list[[2]]
   
@@ -943,7 +944,7 @@ gg_violin_col_facet <- function(data,
         scale_y_continuous(expand = y_expand, breaks = c(0, 1), labels = y_labels, limits = c(0, 1))
     }
     else ({
-      y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_balance, breaks_n = y_breaks_n, zero = y_zero)
+      y_breaks <- sv_numeric_breaks_v(y_var_vctr, balance = y_zero_mid, breaks_n = y_breaks_n, zero = y_zero)
       y_limits <- c(min(y_breaks), max(y_breaks))
       
       plot <- plot +
@@ -961,9 +962,6 @@ gg_violin_col_facet <- function(data,
   }
   
   #colour, titles & facetting
-  if (col_legend_none == TRUE) plot <- plot +
-    theme(legend.position = "none")
-  
   plot <- plot +
     scale_colour_manual(
       values = pal_line,
@@ -988,5 +986,10 @@ gg_violin_col_facet <- function(data,
     ) +
     facet_wrap(vars(!!facet_var), labeller = as_labeller(facet_labels), scales = facet_scales, ncol = facet_ncol, nrow = facet_nrow) 
   
+  if (col_legend_none == TRUE) {
+    plot <- plot +
+      theme(legend.position = "none")
+  }
+
   return(plot)
 }
