@@ -31,7 +31,7 @@ leaf_sf <- function(data,
                     popup_vars_vctr = NULL,
                     popup_numeric_format = function(x) prettyNum(x, big.mark = "", scientific = FALSE),
                     popup_vars_rename = snakecase::to_sentence_case,
-                    pal = pal_viridis_reorder(1),
+                    pal = pal_viridis_mix(1),
                     size_point = 2,
                     size_line = 2,
                     alpha_point = NULL,
@@ -60,7 +60,7 @@ leaf_sf <- function(data,
   
   #colour
   pal <- pal[1]
-
+  
   #basemap
   if (shiny == FALSE) {
     if(basemap == "light") basemap_name <- "CartoDB.PositronNoLabels"
@@ -86,7 +86,7 @@ leaf_sf <- function(data,
     }
     
     popup_data <- popup_data %>%
-        dplyr::mutate_if(.predicate = is.numeric, .funs = popup_numeric_format)
+      dplyr::mutate_if(.predicate = is.numeric, .funs = popup_numeric_format)
     
     popup <- leafpop::popupTable(popup_data, zcol = 1:ncol(popup_data) - 1, row.numbers = FALSE, feature.id = FALSE)
   }
@@ -239,7 +239,7 @@ leaf_sf <- function(data,
 #' @param size_line Size of lines around features (i.e. weight). Defaults to 2.
 #' @param basemap The underlying basemap. Either "light", "dark", "satellite", "street", or "ocean". Defaults to "light". Only applicable where shiny equals FALSE.
 #' @param col_breaks_n For a numeric colour variable, the desired number of intervals on the colour scale. 
-#' @param col_intervals_right For a numeric colour variable, TRUE or FALSE of whether bins or quantiles are to be cut right-closed. Defaults to TRUE.
+#' @param col_intervals_left For a numeric colour variable, TRUE or FALSE of whether bins or quantiles are to be cut left-closed. Defaults to TRUE.
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles. 
 #' @param col_labels A function or named vector to modify the colour scale labels. Defaults to snakecase::to_sentence_case if categorical, and scales::label_comma() if numeric. Use function(x) x to keep labels untransformed.
 #' @param col_legend_none TRUE or FALSE of whether to remove the legend.  
@@ -300,7 +300,7 @@ leaf_sf_col <- function(data,
                         basemap = "light",
                         col_breaks_n = 4,
                         col_cuts = NULL,
-                        col_intervals_right = TRUE,
+                        col_intervals_left = TRUE,
                         col_labels = NULL,
                         col_legend_none = FALSE,
                         col_method = NULL,
@@ -336,7 +336,7 @@ leaf_sf_col <- function(data,
   col_var <- rlang::enquo(col_var)
   label_var <- rlang::enquo(label_var)
   if (is.null(rlang::get_expr(label_var))) label_var <- col_var
-
+  
   #na's
   if (col_na_rm == TRUE) {
     data <- data %>% 
@@ -350,7 +350,7 @@ leaf_sf_col <- function(data,
     dplyr::select(!!label_var) %>% 
     dplyr::mutate_if(.predicate = is.numeric, .funs = label_numeric_format) %>% 
     dplyr::pull(!!label_var)
-
+  
   #logical to factor
   if (is.logical(col_var_vctr)) {
     data <- data %>% 
@@ -395,10 +395,12 @@ leaf_sf_col <- function(data,
     }
     if (anyDuplicated(col_cuts) > 0) stop("col_cuts do not provide unique breaks")
     
-    if (is.null(pal)) pal <- pal_viridis_reorder(length(col_cuts) - 1)
+    if (is.null(pal)) pal <- pal_viridis_mix(length(col_cuts) - 1)
     else if (!is.null(pal)) pal <- pal[1:(length(col_cuts) - 1)]
     if (pal_rev == TRUE) pal <- rev(pal)
     
+    col_intervals_right <- ifelse(col_intervals_left == TRUE, FALSE, TRUE)
+    
     pal_fun <- colorBin(
       palette = pal,
       domain = col_var_vctr,
@@ -408,7 +410,7 @@ leaf_sf_col <- function(data,
     )
     
     if (is.function(col_labels) | is.null(col_labels)) {
-      col_labels <- sv_interval_labels_num(col_cuts, format = col_labels, right_closed = col_intervals_right)
+      col_labels <- sv_interval_labels_num(col_cuts, format = col_labels, left_closed = col_intervals_left)
     }
   }
   else if (col_method == "category") {
@@ -422,7 +424,7 @@ leaf_sf_col <- function(data,
       col_n <- length(col_labels2)
     }) 
     
-    if (is.null(pal)) pal <- pal_d3_reorder(col_n)
+    if (is.null(pal)) pal <- pal_d3_mix(col_n)
     else pal <- pal[1:col_n]
     
     if (is.function(col_labels)) col_labels <- col_labels(col_labels2)
